aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFredrik Thulin <fredrik@thulin.net>2016-06-09 16:01:12 +0200
committerFredrik Thulin <fredrik@thulin.net>2016-06-09 16:01:12 +0200
commitbba436de5395bda8c83a31720a4243eba2646086 (patch)
treeb890dd1303f513d8da1687841efae03ac3f39de6
parent4c13550cf7ca3a5df64c82141980b5db98b58519 (diff)
Put all the keystore commands under 'keystore' instead.
Makes more sense to keep them together, at least in the cli-test.
-rw-r--r--projects/cli-test/Makefile2
-rw-r--r--projects/cli-test/cli-test.c4
-rw-r--r--projects/cli-test/mgmt-keystore.c286
-rw-r--r--projects/cli-test/mgmt-keystore.h (renamed from projects/cli-test/mgmt-set.h)12
-rw-r--r--projects/cli-test/mgmt-set.c146
-rw-r--r--projects/cli-test/mgmt-show.c81
6 files changed, 295 insertions, 236 deletions
diff --git a/projects/cli-test/Makefile b/projects/cli-test/Makefile
index 3e1f225..cc1a281 100644
--- a/projects/cli-test/Makefile
+++ b/projects/cli-test/Makefile
@@ -1,6 +1,6 @@
TEST = cli-test
-OBJS = crc32.o test_sdram.o mgmt-cli.o mgmt-dfu.c mgmt-fpga.c mgmt-misc.c mgmt-show.c mgmt-test.c mgmt-set.c
+OBJS = crc32.o test_sdram.o mgmt-cli.o mgmt-dfu.c mgmt-fpga.c mgmt-misc.c mgmt-show.c mgmt-test.c mgmt-keystore.c
CFLAGS += -I$(LIBCLI_DIR) -I$(LIBHAL_DIR)
LIBS += $(LIBCLI_DIR)/libcli.a
diff --git a/projects/cli-test/cli-test.c b/projects/cli-test/cli-test.c
index b89e7d4..a387751 100644
--- a/projects/cli-test/cli-test.c
+++ b/projects/cli-test/cli-test.c
@@ -40,7 +40,7 @@
#include "mgmt-misc.h"
#include "mgmt-show.h"
#include "mgmt-test.h"
-#include "mgmt-set.h"
+#include "mgmt-keystore.h"
#include <string.h>
@@ -95,7 +95,7 @@ main()
configure_cli_test(&cli);
configure_cli_misc(&cli);
configure_cli_dfu(&cli);
- configure_cli_set(&cli);
+ configure_cli_keystore(&cli);
led_off(LED_RED);
led_on(LED_GREEN);
diff --git a/projects/cli-test/mgmt-keystore.c b/projects/cli-test/mgmt-keystore.c
new file mode 100644
index 0000000..14d8e1b
--- /dev/null
+++ b/projects/cli-test/mgmt-keystore.c
@@ -0,0 +1,286 @@
+/*
+ * mgmt-keystore.c
+ * ---------------
+ * CLI 'keystore' commands.
+ *
+ * Copyright (c) 2016, NORDUnet A/S All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ * - Redistributions of source code must retain the above copyright notice,
+ * this list of conditions and the following disclaimer.
+ *
+ * - Redistributions in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in the
+ * documentation and/or other materials provided with the distribution.
+ *
+ * - Neither the name of the NORDUnet nor the names of its contributors may
+ * be used to endorse or promote products derived from this software
+ * without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+ * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+ * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#define HAL_OK CMSIS_HAL_OK
+
+#include "stm-init.h"
+#include "stm-keystore.h"
+#include "stm-fpgacfg.h"
+#include "stm-uart.h"
+
+#include "mgmt-cli.h"
+#include "mgmt-show.h"
+
+/* Rename both CMSIS HAL_OK and libhal HAL_OK to disambiguate */
+#undef HAL_OK
+#define LIBHAL_OK HAL_OK
+#include "hal.h"
+#define HAL_STATIC_PKEY_STATE_BLOCKS 6
+#include "hal_internal.h"
+#undef HAL_OK
+
+#include <string.h>
+
+
+int cmd_keystore_set_pin(struct cli_def *cli, const char *command, char *argv[], int argc)
+{
+ const hal_ks_keydb_t *db;
+ hal_user_t user;
+ hal_ks_pin_t pin;
+ hal_error_t status;
+
+ db = hal_ks_get_keydb();
+
+ if (db == NULL) {
+ cli_print(cli, "Could not get a keydb from libhal");
+ return CLI_OK;
+ }
+
+ if (argc != 3) {
+ cli_print(cli, "Wrong number of arguments (%i).", argc);
+ cli_print(cli, "Syntax: keystore set pin <user|so|wheel> <iterations> <pin>");
+ return CLI_ERROR;
+ }
+
+ user = HAL_USER_NONE;
+ if (strcmp(argv[0], "user") == 0) user = HAL_USER_NORMAL;
+ if (strcmp(argv[0], "so") == 0) user = HAL_USER_SO;
+ if (strcmp(argv[0], "wheel") == 0) user = HAL_USER_WHEEL;
+ if (user == HAL_USER_NONE) {
+ cli_print(cli, "First argument must be 'user', 'so' or 'wheel' - not '%s'", argv[0]);
+ return CLI_ERROR;
+ }
+
+ pin.iterations = strtol(argv[1], NULL, 0);
+
+ /* We don't actually PBKDF2 the given PIN yet, just testing */
+ strncpy((char *) pin.pin, argv[2], sizeof(pin.pin));
+
+ if ((status = hal_ks_set_pin(user, &pin)) != LIBHAL_OK) {
+ cli_print(cli, "Failed setting PIN: %s", hal_error_string(status));
+ return CLI_ERROR;
+ }
+
+ return CLI_OK;
+}
+
+int cmd_keystore_set_key(struct cli_def *cli, const char *command, char *argv[], int argc)
+{
+ hal_error_t status;
+ int hint = 0;
+
+ if (argc != 2) {
+ cli_print(cli, "Wrong number of arguments (%i).", argc);
+ cli_print(cli, "Syntax: keystore set key <name> <der>");
+ return CLI_ERROR;
+ }
+
+ if ((status = hal_ks_store(HAL_KEY_TYPE_EC_PUBLIC,
+ HAL_CURVE_NONE,
+ 0,
+ (uint8_t *) argv[0], strlen(argv[0]),
+ (uint8_t *) argv[1], strlen(argv[1]),
+ &hint)) != LIBHAL_OK) {
+
+ cli_print(cli, "Failed storing key: %s", hal_error_string(status));
+ return CLI_ERROR;
+ }
+
+ cli_print(cli, "Stored key %i", hint);
+
+ return CLI_OK;
+}
+
+int cmd_keystore_delete_key(struct cli_def *cli, const char *command, char *argv[], int argc)
+{
+ hal_error_t status;
+ int hint = 0;
+
+ if (argc != 1) {
+ cli_print(cli, "Wrong number of arguments (%i).", argc);
+ cli_print(cli, "Syntax: keystore delete key <name>");
+ return CLI_ERROR;
+ }
+
+ if ((status = hal_ks_delete(HAL_KEY_TYPE_EC_PUBLIC,
+ (uint8_t *) argv[0], strlen(argv[0]),
+ &hint)) != LIBHAL_OK) {
+
+ cli_print(cli, "Failed deleting key: %s", hal_error_string(status));
+ return CLI_ERROR;
+ }
+
+ cli_print(cli, "Deleted key %i", hint);
+
+ return CLI_OK;
+}
+
+int cmd_keystore_rename_key(struct cli_def *cli, const char *command, char *argv[], int argc)
+{
+ hal_error_t status;
+ int hint = 0;
+
+ if (argc != 2) {
+ cli_print(cli, "Wrong number of arguments (%i).", argc);
+ cli_print(cli, "Syntax: keystore rename key <name> <new name>");
+ return CLI_ERROR;
+ }
+
+ if ((status = hal_ks_rename(HAL_KEY_TYPE_EC_PUBLIC,
+ (uint8_t *) argv[0], strlen(argv[0]),
+ (uint8_t *) argv[1], strlen(argv[1]),
+ &hint)) != LIBHAL_OK) {
+
+ cli_print(cli, "Failed renaming key: %s", hal_error_string(status));
+ return CLI_ERROR;
+ }
+
+ cli_print(cli, "Renamed key %i", hint);
+
+ return CLI_OK;
+}
+
+int cmd_keystore_show_data(struct cli_def *cli, const char *command, char *argv[], int argc)
+{
+ uint8_t buf[KEYSTORE_PAGE_SIZE];
+ uint32_t i;
+
+ if (keystore_check_id() != 1) {
+ cli_print(cli, "ERROR: The keystore memory is not accessible.");
+ }
+
+ memset(buf, 0, sizeof(buf));
+ if ((i = keystore_read_data(0, buf, sizeof(buf))) != 1) {
+ cli_print(cli, "Failed reading first page from keystore memory: %li", i);
+ return CLI_ERROR;
+ }
+
+ cli_print(cli, "First page from keystore memory:\r\n");
+ uart_send_hexdump(STM_UART_MGMT, buf, 0, sizeof(buf) - 1);
+ uart_send_string2(STM_UART_MGMT, (char *) "\r\n\r\n");
+
+ for (i = 0; i < 8; i++) {
+ if (buf[i] == 0xff) break; /* never written */
+ if (buf[i] != 0x55) break; /* something other than a tombstone */
+ }
+ /* As a demo, tombstone byte after byte of the first 8 bytes in the keystore memory
+ * (as long as they do not appear to contain real data).
+ * If all of them are tombstones, erase the first sector to start over.
+ */
+
+ /*
+ if (i < 8) {
+ if (buf[i] == 0xff) {
+ cli_print(cli, "Tombstoning byte %li", i);
+ buf[i] = 0x55;
+ if ((i = keystore_write_data(0, buf, sizeof(buf))) != 1) {
+ cli_print(cli, "Failed writing data at offset 0: %li", i);
+ return CLI_ERROR;
+ }
+ }
+ } else {
+ cli_print(cli, "Erasing first sector since all the first 8 bytes are tombstones");
+ if ((i = keystore_erase_sectors(1, 1)) != 1) {
+ cli_print(cli, "Failed erasing the first sector: %li", i);
+ return CLI_ERROR;
+ }
+ cli_print(cli, "Erase result: %li", i);
+ }
+ */
+
+ return CLI_OK;
+}
+
+int cmd_keystore_show_keys(struct cli_def *cli, const char *command, char *argv[], int argc)
+{
+ const hal_ks_keydb_t *db;
+
+ db = hal_ks_get_keydb();
+
+ if (db == NULL) {
+ cli_print(cli, "Could not get a keydb from libhal");
+ return CLI_OK;
+ }
+
+ cli_print(cli, "Sizeof db->keys is %i, sizeof one key is %i\n", sizeof(db->keys), sizeof(*db->keys));
+
+ for (int i = 0; i < sizeof(db->keys)/sizeof(*db->keys); i++) {
+ if (! db->keys[i].in_use) {
+ cli_print(cli, "Key %i, not in use", i);
+ } else {
+ cli_print(cli, "Key %i, in use 0x%x, name '%s' der '%s'",
+ i, db->keys[i].in_use, db->keys[i].name, db->keys[i].der);
+ }
+ }
+
+ cli_print(cli, "\nPins:");
+ cli_print(cli, "Wheel iterations: 0x%lx", db->wheel_pin.iterations);
+ cli_print(cli, "SO iterations: 0x%lx", db->so_pin.iterations);
+ cli_print(cli, "User iterations: 0x%lx", db->user_pin.iterations);
+ cli_print(cli, "\n");
+
+ return CLI_OK;
+}
+
+void configure_cli_keystore(struct cli_def *cli)
+{
+ /* keystore */
+ cli_command_root(keystore);
+ /* keystore set */
+ cli_command_branch(keystore, set);
+ /* keystore delete */
+ cli_command_branch(keystore, delete);
+ /* keystore rename */
+ cli_command_branch(keystore, rename);
+ /* keystore show */
+ cli_command_branch(keystore, show);
+
+ /* keystore set pin */
+ cli_command_node(keystore_set, pin, "Set either 'wheel', 'user' or 'so' PIN");
+
+ /* keystore set key */
+ cli_command_node(keystore_set, key, "Set a key");
+
+ /* keystore delete key */
+ cli_command_node(keystore_delete, key, "Delete a key");
+
+ /* keystore rename key */
+ cli_command_node(keystore_rename, key, "Rename a key");
+
+ /* keystore show data */
+ cli_command_node(keystore_show, data, "Dump the first page from the keystore memory");
+
+ /* keystore show keys */
+ cli_command_node(keystore_show, keys, "Show what PINs and keys are in the keystore");
+}
diff --git a/projects/cli-test/mgmt-set.c b/projects/cli-test/mgmt-set.c
deleted file mode 100644
index a9108e7..0000000
--- a/projects/cli-test/mgmt-set.c
+++ /dev/null
@@ -1,146 +0,0 @@
-/*
- * mgmt-set.c
- * -----------
- * CLI 'set' commands.
- *
- * Copyright (c) 2016, NORDUnet A/S All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are
- * met:
- * - Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * - Redistributions in binary form must reproduce the above copyright
- * notice, this list of conditions and the following disclaimer in the
- * documentation and/or other materials provided with the distribution.
- *
- * - Neither the name of the NORDUnet nor the names of its contributors may
- * be used to endorse or promote products derived from this software
- * without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
- * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
- * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
- * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
- * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
-
-#define HAL_OK CMSIS_HAL_OK
-
-#include "stm-init.h"
-#include "stm-keystore.h"
-#include "stm-fpgacfg.h"
-#include "stm-uart.h"
-
-#include "mgmt-cli.h"
-#include "mgmt-show.h"
-
-/* Rename both CMSIS HAL_OK and libhal HAL_OK to disambiguate */
-#undef HAL_OK
-#define LIBHAL_OK HAL_OK
-#include "hal.h"
-#define HAL_STATIC_PKEY_STATE_BLOCKS 6
-#include "hal_internal.h"
-#undef HAL_OK
-
-#include <string.h>
-
-
-int cmd_set_keystore_pin(struct cli_def *cli, const char *command, char *argv[], int argc)
-{
- const hal_ks_keydb_t *db;
- hal_user_t user;
- hal_ks_pin_t pin;
- hal_error_t status;
-
- db = hal_ks_get_keydb();
-
- if (db == NULL) {
- cli_print(cli, "Could not get a keydb from libhal");
- return CLI_OK;
- }
-
- if (argc != 3) {
- cli_print(cli, "Wrong number of arguments (%i).", argc);
- cli_print(cli, "Syntax: set keystore pin <user|so|wheel> <iterations> <pin>");
- return CLI_ERROR;
- }
-
- user = HAL_USER_NONE;
- if (strcmp(argv[0], "user") == 0) user = HAL_USER_NORMAL;
- if (strcmp(argv[0], "so") == 0) user = HAL_USER_SO;
- if (strcmp(argv[0], "wheel") == 0) user = HAL_USER_WHEEL;
- if (user == HAL_USER_NONE) {
- cli_print(cli, "First argument must be 'user', 'so' or 'wheel' - not '%s'", argv[0]);
- return CLI_ERROR;
- }
-
- pin.iterations = strtol(argv[1], NULL, 0);
-
- /* We don't actually PBKDF2 the given PIN yet, just testing */
- strncpy((char *) pin.pin, argv[2], sizeof(pin.pin));
-
- if ((status = hal_ks_set_pin(user, &pin)) != LIBHAL_OK) {
- cli_print(cli, "Failed setting PIN: %s", hal_error_string(status));
- return CLI_ERROR;
- }
-
- return CLI_OK;
-}
-
-int cmd_set_keystore_key(struct cli_def *cli, const char *command, char *argv[], int argc)
-{
- const hal_ks_keydb_t *db;
- hal_error_t status;
- int hint;
-
- db = hal_ks_get_keydb();
-
- if (db == NULL) {
- cli_print(cli, "Could not get a keydb from libhal");
- return CLI_OK;
- }
-
- if (argc != 2) {
- cli_print(cli, "Wrong number of arguments (%i).", argc);
- cli_print(cli, "Syntax: set keystore key <name> <der>");
- return CLI_ERROR;
- }
-
- hint = 0;
- if ((status = hal_ks_store(HAL_KEY_TYPE_EC_PUBLIC,
- HAL_CURVE_NONE,
- 0,
- (uint8_t *) argv[0], strlen(argv[0]),
- (uint8_t *) argv[1], strlen(argv[1]),
- &hint)) != LIBHAL_OK) {
-
- cli_print(cli, "Failed storing key: %s", hal_error_string(status));
- return CLI_ERROR;
- }
-
- cli_print(cli, "Stored key %i", hint);
-
- return CLI_OK;
-}
-
-void configure_cli_set(struct cli_def *cli)
-{
- /* set */
- cli_command_root(set);
- /* set keystore */
- cli_command_branch(set, keystore);
-
- /* set keystore pin */
- cli_command_node(set_keystore, pin, "Set either 'wheel', 'user' or 'so' PIN");
-
- /* set keystore key */
- cli_command_node(set_keystore, key, "Set a key");
-}
diff --git a/projects/cli-test/mgmt-show.c b/projects/cli-test/mgmt-show.c
index 12ea339..80a74cb 100644
--- a/projects/cli-test/mgmt-show.c
+++ b/projects/cli-test/mgmt-show.c
@@ -77,85 +77,6 @@ int cmd_show_keystore_status(struct cli_def *cli, const char *command, char *arg
return CLI_OK;
}
-int cmd_show_keystore_data(struct cli_def *cli, const char *command, char *argv[], int argc)
-{
- uint8_t buf[KEYSTORE_PAGE_SIZE];
- uint32_t i;
-
- if (keystore_check_id() != 1) {
- cli_print(cli, "ERROR: The keystore memory is not accessible.");
- }
-
- memset(buf, 0, sizeof(buf));
- if ((i = keystore_read_data(0, buf, sizeof(buf))) != 1) {
- cli_print(cli, "Failed reading first page from keystore memory: %li", i);
- return CLI_ERROR;
- }
-
- cli_print(cli, "First page from keystore memory:\r\n");
- uart_send_hexdump(STM_UART_MGMT, buf, 0, sizeof(buf) - 1);
- uart_send_string2(STM_UART_MGMT, (char *) "\r\n\r\n");
-
- for (i = 0; i < 8; i++) {
- if (buf[i] == 0xff) break; /* never written */
- if (buf[i] != 0x55) break; /* something other than a tombstone */
- }
- /* As a demo, tombstone byte after byte of the first 8 bytes in the keystore memory
- * (as long as they do not appear to contain real data).
- * If all of them are tombstones, erase the first sector to start over.
- */
- if (i < 8) {
- if (buf[i] == 0xff) {
- cli_print(cli, "Tombstoning byte %li", i);
- buf[i] = 0x55;
- if ((i = keystore_write_data(0, buf, sizeof(buf))) != 1) {
- cli_print(cli, "Failed writing data at offset 0: %li", i);
- return CLI_ERROR;
- }
- }
- } else {
- cli_print(cli, "Erasing first sector since all the first 8 bytes are tombstones");
- if ((i = keystore_erase_sectors(1, 1)) != 1) {
- cli_print(cli, "Failed erasing the first sector: %li", i);
- return CLI_ERROR;
- }
- cli_print(cli, "Erase result: %li", i);
- }
-
- return CLI_OK;
-}
-
-int cmd_show_keystore_keys(struct cli_def *cli, const char *command, char *argv[], int argc)
-{
- const hal_ks_keydb_t *db;
-
- db = hal_ks_get_keydb();
-
- if (db == NULL) {
- cli_print(cli, "Could not get a keydb from libhal");
- return CLI_OK;
- }
-
- cli_print(cli, "Sizeof db->keys is %i, sizeof one key is %i\n", sizeof(db->keys), sizeof(*db->keys));
-
- for (int i = 0; i < sizeof(db->keys)/sizeof(*db->keys); i++) {
- if (! db->keys[i].in_use) {
- cli_print(cli, "Key %i, not in use", i);
- } else {
- cli_print(cli, "Key %i, in use 0x%x, name '%s' der '%s'",
- i, db->keys[i].in_use, db->keys[i].name, db->keys[i].der);
- }
- }
-
- cli_print(cli, "\nPins:");
- cli_print(cli, "Wheel iterations: 0x%lx", db->wheel_pin.iterations);
- cli_print(cli, "SO iterations: 0x%lx", db->so_pin.iterations);
- cli_print(cli, "User iterations: 0x%lx", db->user_pin.iterations);
- cli_print(cli, "\n");
-
- return CLI_OK;
-}
-
void configure_cli_show(struct cli_def *cli)
{
/* show */
@@ -171,6 +92,4 @@ void configure_cli_show(struct cli_def *cli)
cli_command_branch(show, keystore);
/* show keystore status*/
cli_command_node(show_keystore, status, "Show status of the keystore memory");
- cli_command_node(show_keystore, data, "Show the first page of the keystore memory");
- cli_command_node(show_keystore, keys, "List the keys in the keystore database");
}
diff --git a/projects/cli-test/mgmt-set.h b/projects/cli-test/mgmt-keystore.h
index 1772d5b..62efa51 100644
--- a/projects/cli-test/mgmt-set.h
+++ b/projects/cli-test/mgmt-keystore.h
@@ -1,7 +1,7 @@
/*
- * mgmt-set.h
+ * mgmt-keystore.h
* ----------
* Management CLI 'set' functions.
*
* Copyright (c) 2016, NORDUnet A/S All rights reserved.
*
@@ -32,12 +32,12 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef __STM32_CLI_MGMT_SET_H
-#define __STM32_CLI_MGMT_SET_H
+#ifndef __STM32_CLI_MGMT_KEYSTORE_H
+#define __STM32_CLI_MGMT_KEYSTORE_H
#include "stm-init.h"
#include <libcli.h>
-extern void configure_cli_set(struct cli_def *cli);
+extern void configure_cli_keystore(struct cli_def *cli);
-#endif /* __STM32_CLI_MGMT_SET_H */
+#endif /* __STM32_CLI_MGMT_KEYSTORE_H */
@@ -1,7 +1,7 @@
* ----------
- * Management CLI 'set' functions.
+ * Management CLI 'keystore' functions.
*
* Copyright (c) 2016, NORDUnet A/S All rights reserved.